delta: delta test of conditional independence
Description
delta statistic of conditional independence and
associated bootstrap testUsage
delta(x, m, d = 1, eps) delta.test(x, m = 2:3, d = 1,
eps = seq(0.5 * sd(x), 2 * sd(x), length = 4), B = 49)
Arguments
m
vector of embedding dimensions
eps
vector of length scales
B
number of bootstrap replications
Value
delta returns the computed delta statistic.
delta.test returns the bootstrap based 1-sided
p-value.
Warning
Results are sensible to the choice of the window
eps. So, try the test for a grid of m and
eps values. Also, be aware of the course of
dimensionality: m can't be too high for relatively small
time series. See references for further details.Details
delta statistic of conditional independence and
associated bootstrap test. For details, see Manzan(2003).References
Sebastiano Manzan, Essays in Nonlinear Economic Dynamics,
Thela Thesis (2003)See Also
BDS marginal independence test:
bds.test in package tseries Teraesvirta's neural network test for nonlinearity:
terasvirta.test in package
tseries
delta test for nonlinearity: delta.lin.test
Examples
Run this codedelta(log10(lynx), m=3, eps=sd(log10(lynx)))
Run the code above in your browser using DataLab