nlar(str, coefficients, fitted.values, residuals, k,
model, model.specific = NULL, ...)nlar.struct object, i.e. the result
of a call to nlar.structnlar. nlar-methods for a
list of available methods.nlar model class. On a
fitted object you can call some generic methods. For a
list of them, see nlar-methods. An object of the nlar class is a list of (at
least) components: [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]
A nlar object normally should also have a
model-specific subclass (i.e., nlar is a virtual
class).
Each subclass should define at least a print and,
hopefully, a oneStep method, which is used by
predict.nlar to iteratively extend ahead
the time series.
Non-Linear Time Series: A Dynamical Systems Approach, Tong, H., Oxford: Oxford University Press (1990).
availableModels for currently available
built-in models. nlar-methods for available
nlar methods.